Get Type
========

.. automodule:: magql.type

.. autofunction:: magql.type.get_magql_type

.. autofunction:: magql.type.is_required

.. autofunction:: magql.type.get_magql_required_type

.. autofunction:: magql.type.get_magql_filter_type
